==> vector_math-1.1.0.tar.gz: lib/vector_math.dart <==
/*
  Copyright (C) 2013 John McCutchan <john@johnmccutchan.com>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

*/

library vector_math;
import 'dart:typed_data';
import 'dart:math' as Math;

part 'src/vector_math/scalar_math.dart';
part 'src/vector_math/vec2.dart';
part 'src/vector_math/vec3.dart';
part 'src/vector_math/vec4.dart';
part 'src/vector_math/vector.dart';
part 'src/vector_math/trig.dart';
part 'src/vector_math/exponent.dart';
part 'src/vector_math/common.dart';
part 'src/vector_math/handwritten.dart';
part 'src/vector_math/mat2.dart';
part 'src/vector_math/mat3.dart';
part 'src/vector_math/mat4.dart';
part 'src/vector_math/opengl.dart';
part 'src/vector_math/quat.dart';
part 'src/vector_math/aabb3.dart';

==> vector_math-1.3.3.tar.gz: lib/vector_math.dart <==
/*
  Copyright (C) 2013 John McCutchan <john@johnmccutchan.com>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.

*/

library vector_math;
import 'dart:typed_data';
import 'dart:math' as Math;

part 'src/vector_math/angle.dart';
part 'src/vector_math/aabb2.dart';
part 'src/vector_math/aabb3.dart';
part 'src/vector_math/constants.dart';
part 'src/vector_math/error_helpers.dart';
part 'src/vector_math/matrix2.dart';
part 'src/vector_math/matrix3.dart';
part 'src/vector_math/matrix4.dart';
part 'src/vector_math/opengl.dart';
part 'src/vector_math/quaternion.dart';
part 'src/vector_math/vector.dart';
part 'src/vector_math/vector2.dart';
part 'src/vector_math/vector3.dart';
part 'src/vector_math/vector4.dart';
